@@ -55,6 +55,7 @@
 #include "magick/pixel-accessor.h"
 #include "magick/property.h"
 #include "magick/quantum-private.h"
+#include "magick/resource_.h"
 #include "magick/static.h"
 #include "magick/string_.h"
 #include "magick/module.h"
@@ -92,9 +93,6 @@ static Image *ReadLABELImage(const ImageInfo *image_info,
 {
   char
     geometry[MaxTextExtent],
-    *property;
-
-  const char
     *label;
 
   DrawInfo
@@ -127,13 +125,18 @@ static Image *ReadLABELImage(const ImageInfo *image_info,
   (void) ResetImagePage(image,"0x0+0+0");
   if ((image->columns != 0) && (image->rows != 0))
     (void) SetImageBackgroundColor(image);
-  property=InterpretImageProperties(image_info,image,image_info->filename);
-  if (property == (char *) NULL)
+  label=InterpretImageProperties(image_info,image,image_info->filename);
+  if (label == (char *) NULL)
     return(DestroyImageList(image));
-  (void) SetImageProperty(image,"label",property);
-  property=DestroyString(property);
-  label=GetImageProperty(image,"label");
+  (void) SetImageProperty(image,"label",label);
   draw_info=CloneDrawInfo(image_info,(DrawInfo *) NULL);
+  width=(size_t) floor(draw_info->pointsize*strlen(label)+0.5);
+  if (AcquireMagickResource(WidthResource,width) == MagickFalse)
+    {
+      label=DestroyString(label);
+      draw_info=DestroyDrawInfo(draw_info);
+      ThrowReaderException(ImageError,"WidthOrHeightExceedsLimit");
+    }
   draw_info->text=ConstantString(label);
   metrics.width=0.0;
   metrics.height=0.0;
@@ -182,6 +185,7 @@ static Image *ReadLABELImage(const ImageInfo *image_info,
         }
         if (status == MagickFalse)
           {
+            label=DestroyString(label);
             draw_info=DestroyDrawInfo(draw_info);
             image=DestroyImageList(image);
             return((Image *) NULL);
@@ -219,6 +223,7 @@ static Image *ReadLABELImage(const ImageInfo *image_info,
             status=GetMultilineTypeMetrics(image,draw_info,&metrics);
           }
       }
+  label=DestroyString(label);
   if (status == MagickFalse)
     {
       draw_info=DestroyDrawInfo(draw_info);
@@ -257,7 +262,7 @@ static Image *ReadLABELImage(const ImageInfo *image_info,
   (void) FormatLocaleString(geometry,MaxTextExtent,"%+g%+g",
     draw_info->direction == RightToLeftDirection ? (double) image->columns-
     metrics.bounds.x2 : 0.0,draw_info->gravity == UndefinedGravity ?
-    metrics.ascent : 0.0);
+    MagickMax(metrics.ascent,metrics.bounds.y2) : 0.0);
   (void) CloneString(&draw_info->geometry,geometry);
   status=AnnotateImage(image,draw_info);
   if (image_info->pointsize == 0.0)
