@@ -316,7 +316,7 @@ MagickExport Image *CannyEdgeImage(const Image *image,const double radius,
   status=MagickTrue;
   edge_view=AcquireVirtualCacheView(edge_image,exception);
 #if defined(MAGICKCORE_OPENMP_SUPPORT)
-  #pragma omp parallel for schedule(static,4) shared(status) \
+  #pragma omp parallel for schedule(static) shared(status) \
     magick_number_threads(edge_image,edge_image,edge_image->rows,1)
 #endif
   for (y=0; y < (ssize_t) edge_image->rows; y++)
@@ -363,7 +363,7 @@ MagickExport Image *CannyEdgeImage(const Image *image,const double radius,
           { -1.0, -1.0 }
         };
 
-      (void) ResetMagickMemory(&pixel,0,sizeof(pixel));
+      (void) memset(&pixel,0,sizeof(pixel));
       dx=0.0;
       dy=0.0;
       kernel_pixels=p;
@@ -428,7 +428,7 @@ MagickExport Image *CannyEdgeImage(const Image *image,const double radius,
   min=element.intensity;
   edge_view=AcquireAuthenticCacheView(edge_image,exception);
 #if defined(MAGICKCORE_OPENMP_SUPPORT)
-  #pragma omp parallel for schedule(static,4) shared(status) \
+  #pragma omp parallel for schedule(static) shared(status) \
     magick_number_threads(edge_image,edge_image,edge_image->rows,1)
 #endif
   for (y=0; y < (ssize_t) edge_image->rows; y++)
@@ -689,7 +689,7 @@ MagickExport ChannelFeatures *GetImageChannelFeatures(const Image *image,
     sizeof(*channel_features));
   if (channel_features == (ChannelFeatures *) NULL)
     ThrowFatalException(ResourceLimitFatalError,"MemoryAllocationFailed");
-  (void) ResetMagickMemory(channel_features,0,length*
+  (void) memset(channel_features,0,length*
     sizeof(*channel_features));
   /*
     Form grays.
@@ -714,7 +714,7 @@ MagickExport ChannelFeatures *GetImageChannelFeatures(const Image *image,
   status=MagickTrue;
   image_view=AcquireVirtualCacheView(image,exception);
 #if defined(MAGICKCORE_OPENMP_SUPPORT)
-  #pragma omp parallel for schedule(static,4) shared(status) \
+  #pragma omp parallel for schedule(static) shared(status) \
     magick_number_threads(image,image,image->rows,1)
 #endif
   for (y=0; y < (ssize_t) image->rows; y++)
@@ -762,7 +762,7 @@ MagickExport ChannelFeatures *GetImageChannelFeatures(const Image *image,
         channel_features);
       return(channel_features);
     }
-  (void) ResetMagickMemory(&gray,0,sizeof(gray));
+  (void) memset(&gray,0,sizeof(gray));
   for (i=0; i <= (ssize_t) MaxMap; i++)
   {
     if (grays[i].red != ~0U)
@@ -838,20 +838,20 @@ MagickExport ChannelFeatures *GetImageChannelFeatures(const Image *image,
         ResourceLimitError,"MemoryAllocationFailed","`%s'",image->filename);
       return(channel_features);
     }
-  (void) ResetMagickMemory(&correlation,0,sizeof(correlation));
-  (void) ResetMagickMemory(density_x,0,2*(number_grays+1)*sizeof(*density_x));
-  (void) ResetMagickMemory(density_xy,0,2*(number_grays+1)*sizeof(*density_xy));
-  (void) ResetMagickMemory(density_y,0,2*(number_grays+1)*sizeof(*density_y));
-  (void) ResetMagickMemory(&mean,0,sizeof(mean));
-  (void) ResetMagickMemory(sum,0,number_grays*sizeof(*sum));
-  (void) ResetMagickMemory(&sum_squares,0,sizeof(sum_squares));
-  (void) ResetMagickMemory(density_xy,0,2*number_grays*sizeof(*density_xy));
-  (void) ResetMagickMemory(&entropy_x,0,sizeof(entropy_x));
-  (void) ResetMagickMemory(&entropy_xy,0,sizeof(entropy_xy));
-  (void) ResetMagickMemory(&entropy_xy1,0,sizeof(entropy_xy1));
-  (void) ResetMagickMemory(&entropy_xy2,0,sizeof(entropy_xy2));
-  (void) ResetMagickMemory(&entropy_y,0,sizeof(entropy_y));
-  (void) ResetMagickMemory(&variance,0,sizeof(variance));
+  (void) memset(&correlation,0,sizeof(correlation));
+  (void) memset(density_x,0,2*(number_grays+1)*sizeof(*density_x));
+  (void) memset(density_xy,0,2*(number_grays+1)*sizeof(*density_xy));
+  (void) memset(density_y,0,2*(number_grays+1)*sizeof(*density_y));
+  (void) memset(&mean,0,sizeof(mean));
+  (void) memset(sum,0,number_grays*sizeof(*sum));
+  (void) memset(&sum_squares,0,sizeof(sum_squares));
+  (void) memset(density_xy,0,2*number_grays*sizeof(*density_xy));
+  (void) memset(&entropy_x,0,sizeof(entropy_x));
+  (void) memset(&entropy_xy,0,sizeof(entropy_xy));
+  (void) memset(&entropy_xy1,0,sizeof(entropy_xy1));
+  (void) memset(&entropy_xy2,0,sizeof(entropy_xy2));
+  (void) memset(&entropy_y,0,sizeof(entropy_y));
+  (void) memset(&variance,0,sizeof(variance));
   for (i=0; i < (ssize_t) number_grays; i++)
   {
     cooccurrence[i]=(ChannelStatistics *) AcquireQuantumMemory(number_grays,
@@ -860,9 +860,9 @@ MagickExport ChannelFeatures *GetImageChannelFeatures(const Image *image,
     if ((cooccurrence[i] == (ChannelStatistics *) NULL) ||
         (Q[i] == (ChannelStatistics *) NULL))
       break;
-    (void) ResetMagickMemory(cooccurrence[i],0,number_grays*
+    (void) memset(cooccurrence[i],0,number_grays*
       sizeof(**cooccurrence));
-    (void) ResetMagickMemory(Q[i],0,number_grays*sizeof(**Q));
+    (void) memset(Q[i],0,number_grays*sizeof(**Q));
   }
   if (i < (ssize_t) number_grays)
     {
@@ -1094,7 +1094,7 @@ MagickExport ChannelFeatures *GetImageChannelFeatures(const Image *image,
     Compute texture features.
   */
 #if defined(MAGICKCORE_OPENMP_SUPPORT)
-  #pragma omp parallel for schedule(static,4) shared(status) \
+  #pragma omp parallel for schedule(static) shared(status) \
     magick_number_threads(image,image,number_grays,1)
 #endif
   for (i=0; i < 4; i++)
@@ -1279,7 +1279,7 @@ MagickExport ChannelFeatures *GetImageChannelFeatures(const Image *image,
     Compute more texture features.
   */
 #if defined(MAGICKCORE_OPENMP_SUPPORT)
-  #pragma omp parallel for schedule(static,4) shared(status) \
+  #pragma omp parallel for schedule(static) shared(status) \
     magick_number_threads(image,image,number_grays,1)
 #endif
   for (i=0; i < 4; i++)
@@ -1355,7 +1355,7 @@ MagickExport ChannelFeatures *GetImageChannelFeatures(const Image *image,
     Compute more texture features.
   */
 #if defined(MAGICKCORE_OPENMP_SUPPORT)
-  #pragma omp parallel for schedule(static,4) shared(status) \
+  #pragma omp parallel for schedule(static) shared(status) \
     magick_number_threads(image,image,number_grays,1)
 #endif
   for (i=0; i < 4; i++)
@@ -1471,10 +1471,10 @@ MagickExport ChannelFeatures *GetImageChannelFeatures(const Image *image,
   /*
     Compute more texture features.
   */
-  (void) ResetMagickMemory(&variance,0,sizeof(variance));
-  (void) ResetMagickMemory(&sum_squares,0,sizeof(sum_squares));
+  (void) memset(&variance,0,sizeof(variance));
+  (void) memset(&sum_squares,0,sizeof(sum_squares));
 #if defined(MAGICKCORE_OPENMP_SUPPORT)
-  #pragma omp parallel for schedule(static,4) shared(status) \
+  #pragma omp parallel for schedule(static) shared(status) \
     magick_number_threads(image,image,number_grays,1)
 #endif
   for (i=0; i < 4; i++)
@@ -1626,7 +1626,7 @@ MagickExport ChannelFeatures *GetImageChannelFeatures(const Image *image,
     Compute more texture features.
   */
 #if defined(MAGICKCORE_OPENMP_SUPPORT)
-  #pragma omp parallel for schedule(static,4) shared(status) \
+  #pragma omp parallel for schedule(static) shared(status) \
     magick_number_threads(image,image,number_grays,1)
 #endif
   for (i=0; i < 4; i++)
@@ -1642,7 +1642,7 @@ MagickExport ChannelFeatures *GetImageChannelFeatures(const Image *image,
       ChannelStatistics
         pixel;
 
-      (void) ResetMagickMemory(&pixel,0,sizeof(pixel));
+      (void) memset(&pixel,0,sizeof(pixel));
       for (y=0; y < (ssize_t) number_grays; y++)
       {
         register ssize_t
@@ -1833,7 +1833,7 @@ static Image *RenderHoughLines(const ImageInfo *image_info,const size_t columns,
         GetBlobSize(image)+1);
       if (draw_info->primitive != (char *) NULL)
         {
-          (void) CopyMagickMemory(draw_info->primitive,GetBlobStreamData(image),
+          (void) memcpy(draw_info->primitive,GetBlobStreamData(image),
             (size_t) GetBlobSize(image));
           draw_info->primitive[GetBlobSize(image)]='\0';
         }
@@ -2195,7 +2195,7 @@ MagickExport Image *MeanShiftImage(const Image *image,const size_t width,
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
   assert(exception != (ExceptionInfo *) NULL);
   assert(exception->signature == MagickCoreSignature);
-  mean_image=CloneImage(image,image->columns,image->rows,MagickTrue,exception);
+  mean_image=CloneImage(image,0,0,MagickTrue,exception);
   if (mean_image == (Image *) NULL)
     return((Image *) NULL);
   if (SetImageStorageClass(mean_image,DirectClass) == MagickFalse)
@@ -2210,7 +2210,7 @@ MagickExport Image *MeanShiftImage(const Image *image,const size_t width,
   pixel_view=AcquireVirtualCacheView(image,exception);
   mean_view=AcquireAuthenticCacheView(mean_image,exception);
 #if defined(MAGICKCORE_OPENMP_SUPPORT)
-  #pragma omp parallel for schedule(static,4) shared(status,progress) \
+  #pragma omp parallel for schedule(static) shared(status,progress) \
     magick_number_threads(mean_image,mean_image,mean_image->rows,1)
 #endif
   for (y=0; y < (ssize_t) mean_image->rows; y++)
